@@ -1,6 +1,6 @@
 package Apache::AuthCookie;
 BEGIN {
-  $Apache::AuthCookie::VERSION = '3.14';
+  $Apache::AuthCookie::VERSION = '3.15';
 }
 
 # ABSTRACT: Perl Authentication and Authorization via cookies
@@ -15,6 +15,10 @@ use Apache::Util qw(escape_uri);
 
 sub recognize_user ($$) {
     my ($self, $r) = @_;
+
+    # only check if user is not already set
+    return DECLINED if $r->connection->user;
+
     my $debug = $r->dir_config("AuthCookieDebug") || 0;
     my ($auth_type, $auth_name) = ($r->auth_type, $r->auth_name);
 
@@ -439,12 +443,20 @@ sub send_cookie {
     );
 
     # add P3P header if user has configured it.
+    $self->send_p3p($r);
+
+    $r->err_headers_out->add("Set-Cookie" => $cookie);
+}
+
+# send a P3P header if it is configured as ${auth_name}P3P
+sub send_p3p {
+    my ($self, $r) = @_;
+
     my $auth_name = $r->auth_name;
+
     if (my $p3p = $r->dir_config("${auth_name}P3P")) {
         $r->err_header_out(P3P => $p3p);
     }
-
-    $r->err_headers_out->add("Set-Cookie" => $cookie);
 }
 
 sub cookie_string {
@@ -532,7 +544,7 @@ Apache::AuthCookie - Perl Authentication and Authorization via cookies
 
 =head1 VERSION
 
-version 3.14
+version 3.15
 
 =head1 SYNOPSIS
 
@@ -1058,7 +1070,7 @@ L<perl(1)>, L<mod_perl(1)>, L<Apache(1)>.
 
 =head1 AUTHOR
 
-  Michael Schout <mschout@cpan.org>
+Michael Schout <mschout@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
@@ -1067,14 +1079,6 @@ This software is copyright (c) 2000 by Ken Williams.
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
-=head1 SOURCE
-
-You can contribute or fork this project via github:
-
-http://github.com/mschout/apache-authcookie
-
- git clone git://github.com/mschout/apache-authcookie.git
-
 =head1 BUGS
 
 Please report any bugs or feature requests to bug-apache-authcookie@rt.cpan.org or through the web interface at:
